==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Appel"

, "Calls"
: "Appels"

, "Line"
: "Ligne"

, "Caller Id"
: "Identité de l'appelant"

, "Start"
: "Début"

, "Connected"
: "Connecté"

, "Disconnected"
: "Déconnecté"

, "Duration"
: "Durée"

, "Ringing"
: "Appel"

, "Direction"
: "Direction"

, "Source"
: "Source"

, "Destination"
: "Destination"

, "Phone"
: "Téléphone"

, "Phones"
: "Téléphones"

, "Settings"
: "Paramètres"

, "Lines"
: "Lignes"

, "Description"
: "Description"

, "Number"
: "Numéro"

, "Cancel"
: "Annuler"

, "Dial"
: "Composer"

, "Error"
: "Erreur"

, "Not possible to dial."
: "Numérotation impossible."

, "Edit phone settings"
: "Éditer les paramètres du téléphone"

, "Dial number"
: "Composer numéro"

, "Initiate a new outgoing call"
: "Faire un nouvel appel"

, "No phone selected"
: "Aucun téléphone sélectionné"

, "Please select the desired phone in the tree!"
: "Sélectionnez un téléphone dans les choix"

, "Call contact"
: "Appeler le contact"

, "Work"
: "Travail"

, "Home"
: "Domicile"

, "Cell"
: "Mobile"

, "Cell private"
: "Mobile personnel"

, "Incoming call"
: "Appel entrant"

, "Outgoing call"
: "Appel sortant"

, "unknown number"
: "numéro inconnu"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Appels de cette semaine"

, "Incoming and outgoing calls of this week"
: "Appels entrants et sortants de cette semaine"

, "Calls last week"
: "Appels de la semaine dernière"

, "Incoming and outgoing calls of last week"
: "Appels entrants et sortants de la semaine dernière"

, "Calls this month"
: "Appels de ce mois"

, "Incoming and outgoing calls of this month"
: "Appels entrants et sortants de ce mois"

, "Calls last month"
: "Appels du mois précédent"

, "Incoming and outgoing calls of last month"
: "Appels entrants et sortants du mois dernier"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Appel entrant"

, "Outgoing call"
: "Appel sortant"

, "unknown number"
: "numéro inconnu"

, "Phone"
: "Téléphone"

, "Line"
: "Ligne"

, "Number"
: "Numéro"

, "Cancel"
: "Annuler"

, "Dial"
: "Composer"

, "Error"
: "Erreur"

, "Not possible to dial."
: "Numérotation impossible."

, "Call contact"
: "Appeler le contact"

, "Work"
: "Travail"

, "Home"
: "Domicile"

, "Cell"
: "Mobile"

, "Cell private"
: "Mobile personnel"

, "Edit phone settings"
: "Éditer les paramètres du téléphone"

, "Dial number"
: "Composer numéro"

, "Initiate a new outgoing call"
: "Faire un nouvel appel"

, "Phones"
: "Téléphones"

, "No phone selected"
: "Aucun téléphone sélectionné"

, "Please select the desired phone in the tree!"
: "Sélectionnez un téléphone dans les choix"

, "Calls this week"
: "Appels de cette semaine"

, "Calls last week"
: "Appels de la semaine dernière"

, "Calls this month"
: "Appels de ce mois"

, "Calls last month"
: "Appels du mois précédent"

, "Incoming and outgoing calls of this week"
: "Appels entrants et sortants de cette semaine"

, "Incoming and outgoing calls of last week"
: "Appels entrants et sortants de la semaine dernière"

, "Incoming and outgoing calls of this month"
: "Appels entrants et sortants de ce mois"

, "Incoming and outgoing calls of last month"
: "Appels entrants et sortants du mois dernier"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Appel"

, "Calls"
: "Appels"

, "Caller Id"
: "Identité de l'appelant"

, "Start"
: "Début"

, "Connected"
: "Connecté"

, "Disconnected"
: "Déconnecté"

, "Duration"
: "Durée"

, "Ringing"
: "Appel"

, "Direction"
: "Direction"

, "Source"
: "Source"

, "Destination"
: "Destination"

, "resolved destination"
: ""

, "Settings"
: "Paramètres"

, "Lines"
: "Lignes"

, "Description"
: "Description"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
